==> qt-creator-opensource-src-3.1.2.zip: qt-creator-opensource-src-3.1.2/src/plugins/qmlprofiler/abstracttimelinemodel_p.h <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef ABSTRACTTIMELINEMODEL_P_H
#define ABSTRACTTIMELINEMODEL_P_H

#include "abstracttimelinemodel.h"

namespace QmlProfiler {

class QMLPROFILER_EXPORT AbstractTimelineModel::AbstractTimelineModelPrivate {
public:
    virtual ~AbstractTimelineModelPrivate() {}

    virtual int count() const = 0;
    virtual qint64 duration(int index) const = 0;
    virtual qint64 startTime(int index) const = 0;
    virtual qint64 lastEndTime() const = 0;
    virtual qint64 firstStartTime() const = 0;
    virtual int findFirstIndex(qint64 startTime) const = 0;
    virtual int findFirstIndexNoParents(qint64 startTime) const = 0;
    virtual int findLastIndex(qint64 endTime) const = 0;

    QString name;
    QmlProfilerModelManager *modelManager;
    int modelId;

protected:
    AbstractTimelineModel *q_ptr;

private:
    Q_DECLARE_PUBLIC(AbstractTimelineModel)
};

}
#endif // ABSTRACTTIMELINEMODEL_P_H

==> qt-creator-opensource-src-3.2.2.zip: qt-creator-opensource-src-3.2.2/src/plugins/qmlprofiler/abstracttimelinemodel_p.h <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://www.qt.io/licensing.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef ABSTRACTTIMELINEMODEL_P_H
#define ABSTRACTTIMELINEMODEL_P_H

#include "abstracttimelinemodel.h"

namespace QmlProfiler {

class QMLPROFILER_EXPORT AbstractTimelineModel::AbstractTimelineModelPrivate {
public:
    virtual ~AbstractTimelineModelPrivate() {}

    virtual int count() const = 0;
    virtual qint64 duration(int index) const = 0;
    virtual qint64 startTime(int index) const = 0;
    virtual qint64 lastEndTime() const = 0;
    virtual qint64 firstStartTime() const = 0;
    virtual int findFirstIndex(qint64 startTime) const = 0;
    virtual int findFirstIndexNoParents(qint64 startTime) const = 0;
    virtual int findLastIndex(qint64 endTime) const = 0;

    QVector<int> rowOffsets;
    QString name;
    QmlProfilerModelManager *modelManager;
    int modelId;
    bool expanded;
    QString title;
    QmlDebug::Message message;
    QmlDebug::RangeType rangeType;

protected:
    AbstractTimelineModel *q_ptr;

private:
    Q_DECLARE_PUBLIC(AbstractTimelineModel)
};

}
#endif // ABSTRACTTIMELINEMODEL_P_H
